==> kubernetes-model-1.0.30-sources.jar: annotations/io/fabric8/kubernetes/api/model/SecretVolumeSourceFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import java.util.Map;
import java.util.HashMap;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Visitable;

public class SecretVolumeSourceFluentImpl<T extends SecretVolumeSourceFluent<T>> extends BaseFluent<T> implements SecretVolumeSourceFluent<T>{

     String secretName;     Map<String, Object> additionalProperties = new HashMap();

    public String getSecretName(){
    return this.secretName;
    }
    public T withSecretName( String secretName){
    this.secretName=secretName; return (T) this;
    }
    public T addToAdditionalProperties( String key,  Object value){
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (T)this;
    }
    public T removeFromAdditionalProperties( String key){
    if(key != null) {this.additionalProperties.remove(key);} return (T)this;
    }
    public Map<String, Object> getAdditionalProperties(){
    return this.additionalProperties;
    }
    public T withAdditionalProperties( Map<String, Object> additionalProperties){
    this.additionalProperties.clear();if (additionalProperties != null) {this.additionalProperties.putAll(additionalProperties);} return (T) this;
    }
    public boolean equals( Object o){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
SecretVolumeSourceFluentImpl that = (SecretVolumeSourceFluentImpl) o;
if (secretName != null ? !secretName.equals(that.secretName) :that.secretName != null) return false;
if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
return true;

    }



}

==> kubernetes-model-1.0.40-sources.jar: annotations/io/fabric8/kubernetes/api/model/SecretVolumeSourceFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import java.util.Map;
import java.util.HashMap;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Visitable;

public class SecretVolumeSourceFluentImpl<T extends SecretVolumeSourceFluent<T>> extends BaseFluent<T> implements SecretVolumeSourceFluent<T>{

     String secretName;     Map<String, Object> additionalProperties = new HashMap();
public SecretVolumeSourceFluentImpl(){
    
}
public SecretVolumeSourceFluentImpl( SecretVolumeSource instance ){
    this.withSecretName(instance.getSecretName()); 
}

    public String getSecretName(){
    return this.secretName;
    }
    public T withSecretName( String secretName){
    this.secretName=secretName; return (T) this;
    }
    public T addToAdditionalProperties( String key,  Object value){
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (T)this;
    }
    public T addToAdditionalProperties( Map<String, Object> map){
    if(map != null) { this.additionalProperties.putAll(map);} return (T)this;
    }
    public T removeFromAdditionalProperties( String key){
    if(key != null) {this.additionalProperties.remove(key);} return (T)this;
    }
    public T removeFromAdditionalProperties( Map<String, Object> map){
    if(map != null) { for(Object key : map.keySet()) {this.additionalProperties.remove(key);}} return (T)this;
    }
    public Map<String, Object> getAdditionalProperties(){
    return this.additionalProperties;
    }
    public T withAdditionalProperties( Map<String, Object> additionalProperties){
    this.additionalProperties.clear();if (additionalProperties != null) {this.additionalProperties.putAll(additionalProperties);} return (T) this;
    }
    public boolean equals( Object o){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
SecretVolumeSourceFluentImpl that = (SecretVolumeSourceFluentImpl) o;
if (secretName != null ? !secretName.equals(that.secretName) :that.secretName != null) return false;
if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
return true;

    }



}
